@@ -61,6 +61,9 @@ class Sequential:
   
   def fit(self, x, y, batch_size=None, epochs=None,verbose=None, validation_split=None, early_stop = None):
     
+    if len(y.shape) == 1:
+      y = y.reshape(-1,1)
+
     if batch_size is None:
       batch_size = self.batch_size_
     if epochs is None:
